"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@yarnpkg/core");
const core_2 = require("@yarnpkg/core");
const fslib_1 = require("@yarnpkg/fslib");
const githubUtils = __importStar(require("./githubUtils"));
class GithubFetcher {
    supports(locator, opts) {
        if (!githubUtils.isGithubUrl(locator.reference))
            return false;
        return true;
    }
    getLocalPath(locator, opts) {
        return null;
    }
    async fetch(locator, opts) {
        const expectedChecksum = opts.checksums.get(locator.locatorHash) || null;
        const [packageFs, releaseFs, checksum] = await opts.cache.fetchPackageFromCache(locator, expectedChecksum, async () => {
            opts.report.reportInfoOnce(core_1.MessageName.FETCH_NOT_CACHED, `${core_2.structUtils.prettyLocator(opts.project.configuration, locator)} can't be found in the cache and will be fetched from the remote repository`);
            return await this.fetchFromNetwork(locator, opts);
        });
        return {
            packageFs,
            releaseFs,
            prefixPath: core_2.structUtils.getIdentVendorPath(locator),
            checksum,
        };
    }
    async fetchFromNetwork(locator, opts) {
        const sourceBuffer = await core_2.httpUtils.get(this.getLocatorUrl(locator, opts), {
            configuration: opts.project.configuration,
        });
        return await fslib_1.xfs.mktempPromise(async (extractPath) => {
            const extractTarget = new fslib_1.CwdFS(extractPath);
            await core_2.tgzUtils.extractArchiveTo(sourceBuffer, extractTarget, {
                stripComponents: 1,
            });
            const packagePath = fslib_1.ppath.join(extractPath, `package.tgz`);
            await core_2.scriptUtils.prepareExternalProject(extractPath, packagePath, {
                configuration: opts.project.configuration,
                report: opts.report,
            });
            const packedBuffer = await fslib_1.xfs.readFilePromise(packagePath);
            return await core_2.tgzUtils.convertToZip(packedBuffer, {
                compressionLevel: opts.project.configuration.get(`compressionLevel`),
                prefixPath: core_2.structUtils.getIdentVendorPath(locator),
                stripComponents: 1,
            });
        });
    }
    getLocatorUrl(locator, opts) {
        const { auth, username, reponame, treeish } = githubUtils.parseGithubUrl(locator.reference);
        return `https://${auth ? `${auth}@` : ``}github.com/${username}/${reponame}/archive/${treeish}.tar.gz`;
    }
}
exports.GithubFetcher = GithubFetcher;
